'use strict';
import request 		from '@/service/common/request';
import cache 		from '@/service/common/cache';
import config 		from '@/service/common/config';
import image 		from 'vue-como-image';
import APIURL 		from '@/service/common/api.config';
import echarts 		from 'echarts';
import basics_home 	from '@/service/basics/index';
import adminAuth 	from '@/service/common/auth';
import store 		from '@/store';
import formDialog 	from '@/components/basics/form_dialog.vue';
import comoLayer 	from 'vue-como-layer';

export let Basics = Object.assign({},basics_home);
/**
 * [获取窗口最大宽高]
 * @author    szjcomo
 * @date   		2020-10-17
 * @return {[type]}     [description]
 */
export const layerDialogMaxWH = (wRadio = 0.8,hRadio = 0.8) => {
	let windowHeight = document.body.clientHeight;
	let windowWidth  = document.body.clientWidth;
	return {width:windowWidth * wRadio,height:windowHeight * hRadio};
} 

/**
 * [authCheck 权限检测函数]
 * @author    szjcomo
 * @date   		2020-10-22
 * @param  {[type]}     router_name [description]
 * @return {[type]}                 [description]
 */
export const authCheck = async function(router_name) {
	return await store.dispatch('authRouters',router_name);
}
/**
 * [Dialog description]
 * @author    szjcomo
 * @date   		2020-10-22
 * @param  {Object}     params [description]
 */
export const Dialog = function(dialog_options = {title:'数据操作',shade:true},options = {}) {
	return comoLayer.iframe(formDialog,dialog_options,options);
}
/**
 * [ActionException 展示提示信息展示]
 * @author    szjcomo
 * @date   		2020-10-31
 * @param  {[type]}     message [description]
 * @param  {Object}     options [description]
 */
export const ActionException = function(message,options = {}) {
	let default_options = Object.assign({title:'信息操作失败提醒',shade:true,icon:2},options);
	return comoLayer.alert(message,default_options);
}


export default {
	basics:Basics,
	upload:request.upload,
	cache:cache,
	config:config,
	image:image,
	apiurl:APIURL,
	request:request,
	echarts:echarts,
	dialogMax:layerDialogMaxWH,
	auth:adminAuth,
	authCheck:authCheck,
	dialog:Dialog,
	exception:ActionException
};